function [C_DR, BS] = building_measures(x,y,z)
%building_measures is the version 0.1 to evaluate 
% performance on building SAR simulated images as described in 
% "Benchmarking framework for SAR despeckling", written by
% G. Di Martino, M. Poderico, G. Poggi, D.Riccio and L. Verdoliva, 
% IEEE Trans. on Geoscience and Remote Sensing, in press, 2013.
% Please cite this paper when using these measures.
%
% Building measures 
% [C_DR, BS] = building_measures(x,y,z)
% x: clean image, y: filtered image; z: noisy image (all intensity format)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% Copyright (c) 2013 Image Processing Research Group of University Federico II of Naples ('GRIP-UNINA').
% All rights reserved.
% this software should be used, reproduced and modified only for informational and nonprofit purposes.
% 
% By downloading and/or using any of these files, you implicitly agree to all the
% terms of the license, as specified in the document LICENSE.txt
% (included in this package) and online at
% http://www.grip.unina.it/download/LICENSE_OPEN.txt
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Contrast measure
y_DR = mean2(y(122:136,128:129));
section1 = y(1:101,1:101);     m1 = mean2(section1);
section2 = y(156:256,1:101);   m2 = mean2(section2);
section3 = y(1:101,156:256);   m3 = mean2(section3);
section4 = y(156:256,156:256); m4 = mean2(section4);
y_BG = (m1+m2+m3+m4)/4;
C_DR = 10*log10(y_DR/y_BG);

% Building smearing
med = log10(mean(x(122:136,:))+eps);
fil = log10(mean(y(122:136,:))+eps);
a = 2;
s = [112:144];
si = [112:1/a:144];
originale = interp1(s,med(112:144),si,'linear');
filtrata = interp1(s,fil(112:144),si,'linear');
BS = sum(abs(filtrata-originale))/a;

% Display of results
figure(1); W=16; a = 6;
s = [128-W:128+W];
si = [128-W:1/a:128+W];
med = log10(mean(x(122:136,:))+eps);
fil = log10(mean(y(122:136,:))+eps);
plot([-W:1/a:W],interp1(s,med(128-W:128+W),si,'spline'),'k-','LineWidth',2); 
hold on;
plot([-W:1/a:W],interp1(s,fil(128-W:128+W),si,'spline'),'r-','LineWidth',2);  
hold off;
axis([-15 +15 -2.7 4]);
title('building profile');
